@@ -1,11 +1,12 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use ast_view::{RootNode, Spanned};
+use deno_ast::swc::common::comments::Comment;
+use deno_ast::swc::common::comments::CommentKind;
+use deno_ast::swc::common::Span;
+use deno_ast::view as ast_view;
+use deno_ast::view::{RootNode, Spanned};
 use once_cell::sync::Lazy;
 use regex::Regex;
 use std::collections::HashMap;
-use swc_common::comments::Comment;
-use swc_common::comments::CommentKind;
-use swc_common::Span;
 
 pub type LineIgnoreDirective = IgnoreDirective<Line>;
 pub type FileIgnoreDirective = IgnoreDirective<File>;
