@@ -3,6 +3,7 @@ use crate::context::Context;
 use crate::Program;
 use crate::ProgramRef;
 use std::collections::HashSet;
+use std::sync::Arc;
 
 pub mod adjacent_overload_signatures;
 pub mod ban_ts_comment;
@@ -83,6 +84,7 @@ pub mod no_var;
 pub mod no_window_prefix;
 pub mod no_with;
 pub mod prefer_as_const;
+pub mod prefer_ascii;
 pub mod prefer_const;
 pub mod prefer_namespace_keyword;
 pub mod prefer_primordials;
@@ -95,7 +97,7 @@ pub mod valid_typeof;
 
 const DUMMY_NODE: () = ();
 
-pub trait LintRule {
+pub trait LintRule: std::fmt::Debug + Send + Sync {
   /// Creates an instance of this rule.
   fn new() -> Box<Self>
   where
@@ -138,7 +140,76 @@ pub trait LintRule {
   fn docs(&self) -> &'static str;
 }
 
-pub fn get_all_rules() -> Vec<Box<dyn LintRule>> {
+pub fn get_all_rules() -> Arc<Vec<Box<dyn LintRule>>> {
+  Arc::new(get_all_rules_raw())
+}
+
+pub fn get_recommended_rules() -> Arc<Vec<Box<dyn LintRule>>> {
+  Arc::new(
+    get_all_rules_raw()
+      .into_iter()
+      .filter(|r| r.tags().contains(&"recommended"))
+      .collect(),
+  )
+}
+
+/// Returns a list of rules after filtering.
+///
+/// Following rules are applied (in the described order):
+///
+/// - if `maybe_tags` is `None` then all defined rules are returned, otherwise
+///   only rules matching at least one tag will be returned; if provided list
+///   is empty then all rules will be excluded by default
+///
+/// - if `maybe_exclude` is `Some`, all rules with matching codes will
+///   be filtered out
+///
+/// - if `maybe_include` is `Some`, rules with matching codes will be added
+///   to the return list
+///
+/// Before returning the list will sorted alphabetically.
+pub fn get_filtered_rules(
+  maybe_tags: Option<Vec<String>>,
+  maybe_exclude: Option<Vec<String>>,
+  maybe_include: Option<Vec<String>>,
+) -> Arc<Vec<Box<dyn LintRule>>> {
+  let tags_set =
+    maybe_tags.map(|tags| tags.into_iter().collect::<HashSet<_>>());
+
+  let mut rules = get_all_rules_raw()
+    .into_iter()
+    .filter(|rule| {
+      let mut passes = if let Some(tags_set) = &tags_set {
+        rule
+          .tags()
+          .iter()
+          .any(|t| tags_set.contains(&t.to_string()))
+      } else {
+        true
+      };
+
+      if let Some(excludes) = &maybe_exclude {
+        if excludes.contains(&rule.code().to_owned()) {
+          passes &= false;
+        }
+      }
+
+      if let Some(includes) = &maybe_include {
+        if includes.contains(&rule.code().to_owned()) {
+          passes |= true;
+        }
+      }
+
+      passes
+    })
+    .collect::<Vec<_>>();
+
+  rules.sort_by_key(|r| r.code());
+
+  Arc::new(rules)
+}
+
+fn get_all_rules_raw() -> Vec<Box<dyn LintRule>> {
   vec![
     adjacent_overload_signatures::AdjacentOverloadSignatures::new(),
     ban_ts_comment::BanTsComment::new(),
@@ -219,6 +290,7 @@ pub fn get_all_rules() -> Vec<Box<dyn LintRule>> {
     no_window_prefix::NoWindowPrefix::new(),
     no_with::NoWith::new(),
     prefer_as_const::PreferAsConst::new(),
+    prefer_ascii::PreferAscii::new(),
     prefer_const::PreferConst::new(),
     prefer_namespace_keyword::PreferNamespaceKeyword::new(),
     prefer_primordials::PreferPrimordials::new(),
@@ -231,79 +303,22 @@ pub fn get_all_rules() -> Vec<Box<dyn LintRule>> {
   ]
 }
 
-pub fn get_recommended_rules() -> Vec<Box<dyn LintRule>> {
-  get_all_rules()
-    .into_iter()
-    .filter(|r| r.tags().contains(&"recommended"))
-    .collect()
-}
-
-/// Returns a list of rules after filtering.
-///
-/// Following rules are applied (in the described order):
-///
-/// - if `maybe_tags` is `None` then all defined rules are returned, otherwise
-///   only rules matching at least one tag will be returned; if provided list
-///   is empty then all rules will be excluded by default
-///
-/// - if `maybe_exclude` is `Some`, all rules with matching codes will
-///   be filtered out
-///
-/// - if `maybe_include` is `Some`, rules with matching codes will be added
-///   to the return list
-///
-/// Before returning the list will sorted alphabetically.
-pub fn get_filtered_rules(
-  maybe_tags: Option<Vec<String>>,
-  maybe_exclude: Option<Vec<String>>,
-  maybe_include: Option<Vec<String>>,
-) -> Vec<Box<dyn LintRule>> {
-  let tags_set =
-    maybe_tags.map(|tags| tags.into_iter().collect::<HashSet<_>>());
-
-  let mut rules = get_all_rules()
-    .into_iter()
-    .filter(|rule| {
-      let mut passes = if let Some(tags_set) = &tags_set {
-        rule
-          .tags()
-          .iter()
-          .any(|t| tags_set.contains(&t.to_string()))
-      } else {
-        true
-      };
-
-      if let Some(excludes) = &maybe_exclude {
-        if excludes.contains(&rule.code().to_owned()) {
-          passes &= false;
-        }
-      }
-
-      if let Some(includes) = &maybe_include {
-        if includes.contains(&rule.code().to_owned()) {
-          passes |= true;
-        }
-      }
-
-      passes
-    })
-    .collect::<Vec<_>>();
-
-  rules.sort_by_key(|r| r.code());
-
-  rules
-}
-
 #[cfg(test)]
 mod tests {
   use super::*;
 
   #[test]
   fn recommended_rules_sorted_alphabetically() {
-    let mut recommended_rules = get_recommended_rules();
-    recommended_rules.sort_by_key(|r| r.code());
-    for (sorted, unsorted) in
-      recommended_rules.into_iter().zip(get_recommended_rules())
+    let sorted_recommended_rules = {
+      let mut recommended_rules =
+        Arc::try_unwrap(get_recommended_rules()).unwrap();
+      recommended_rules.sort_by_key(|r| r.code());
+      Arc::new(recommended_rules)
+    };
+
+    for (sorted, unsorted) in sorted_recommended_rules
+      .iter()
+      .zip(get_recommended_rules().iter())
     {
       assert_eq!(sorted.code(), unsorted.code());
     }
@@ -311,9 +326,9 @@ mod tests {
 
   #[test]
   fn all_rules_sorted_alphabetically() {
-    let mut all_rules = get_all_rules();
+    let mut all_rules = get_all_rules_raw();
     all_rules.sort_by_key(|r| r.code());
-    for (sorted, unsorted) in all_rules.into_iter().zip(get_all_rules()) {
+    for (sorted, unsorted) in all_rules.iter().zip(get_all_rules_raw()) {
       assert_eq!(sorted.code(), unsorted.code());
     }
   }
@@ -322,7 +337,7 @@ mod tests {
   fn test_get_filtered_rules() {
     let rules =
       get_filtered_rules(Some(vec!["recommended".to_string()]), None, None);
-    for (r, rr) in rules.into_iter().zip(get_recommended_rules()) {
+    for (r, rr) in rules.iter().zip(get_recommended_rules().iter()) {
       assert_eq!(r.code(), rr.code());
     }
 
@@ -360,4 +375,25 @@ mod tests {
     );
     assert_eq!(rules.len(), get_recommended_rules().len());
   }
+
+  #[test]
+  fn ensure_lint_rules_are_sharable_across_threads() {
+    use std::thread::spawn;
+
+    let rules = Arc::new(get_recommended_rules());
+    let handles = (0..2)
+      .map(|_| {
+        let rules = Arc::clone(&rules);
+        spawn(move || {
+          for rule in rules.iter() {
+            assert!(rule.tags().contains(&"recommended"));
+          }
+        })
+      })
+      .collect::<Vec<_>>();
+
+    for handle in handles {
+      handle.join().unwrap();
+    }
+  }
 }
