@@ -2,9 +2,11 @@
 use super::{Context, LintRule};
 use crate::handler::{Handler, Traverse};
 use crate::{Program, ProgramRef};
-use ast_view::{Span, Spanned};
+use deno_ast::view as ast_view;
+use deno_ast::view::{Span, Spanned};
 use if_chain::if_chain;
 
+#[derive(Debug)]
 pub struct ConstructorSuper;
 
 const CODE: &str = "constructor-super";
