@@ -1,12 +1,13 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
 use super::{Context, LintRule, DUMMY_NODE};
 use crate::ProgramRef;
+use deno_ast::swc::ast::{BinExpr, BinaryOp};
+use deno_ast::swc::visit::noop_visit_type;
+use deno_ast::swc::visit::Node;
+use deno_ast::swc::visit::Visit;
 use derive_more::Display;
-use swc_ecmascript::ast::{BinExpr, BinaryOp};
-use swc_ecmascript::visit::noop_visit_type;
-use swc_ecmascript::visit::Node;
-use swc_ecmascript::visit::Visit;
 
+#[derive(Debug)]
 pub struct Eqeqeq;
 
 const CODE: &str = "eqeqeq";
@@ -78,7 +79,7 @@ impl<'c, 'view> Visit for EqeqeqVisitor<'c, 'view> {
         .context
         .add_diagnostic_with_hint(bin_expr.span, CODE, message, hint)
     }
-    swc_ecmascript::visit::visit_bin_expr(self, bin_expr, parent);
+    deno_ast::swc::visit::visit_bin_expr(self, bin_expr, parent);
   }
 }
 
