@@ -1,17 +1,18 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
 use super::{Context, LintRule, DUMMY_NODE};
 use crate::ProgramRef;
+use deno_ast::swc::common::Span;
+use deno_ast::swc::visit::noop_visit_type;
+use deno_ast::swc::visit::Node;
+use deno_ast::swc::visit::Visit;
 use derive_more::Display;
-use swc_common::Span;
-use swc_ecmascript::visit::noop_visit_type;
-use swc_ecmascript::visit::Node;
-use swc_ecmascript::visit::Visit;
 
-use swc_ecmascript::ast::{
+use deno_ast::swc::ast::{
   ArrowExpr, Class, ClassMember, Decl, DefaultDecl, Expr, Function, ModuleDecl,
   Pat, TsKeywordTypeKind, TsType, TsTypeAnn, VarDecl,
 };
 
+#[derive(Debug)]
 pub struct ExplicitModuleBoundaryTypes;
 
 const CODE: &str = "explicit-module-boundary-types";
