@@ -1,14 +1,15 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
 use super::{Context, LintRule, DUMMY_NODE};
 use crate::ProgramRef;
+use deno_ast::swc::ast::Expr;
+use deno_ast::swc::ast::UnaryExpr;
+use deno_ast::swc::ast::UnaryOp;
+use deno_ast::swc::visit::noop_visit_type;
+use deno_ast::swc::visit::Node;
+use deno_ast::swc::visit::Visit;
 use derive_more::Display;
-use swc_ecmascript::ast::Expr;
-use swc_ecmascript::ast::UnaryExpr;
-use swc_ecmascript::ast::UnaryOp;
-use swc_ecmascript::visit::noop_visit_type;
-use swc_ecmascript::visit::Node;
-use swc_ecmascript::visit::Visit;
 
+#[derive(Debug)]
 pub struct NoDeleteVar;
 
 const CODE: &str = "no-delete-var";
