@@ -2,12 +2,14 @@
 use super::{Context, LintRule};
 use crate::handler::{Handler, Traverse};
 use crate::{Program, ProgramRef};
+use deno_ast::swc::atoms::JsWord;
+use deno_ast::swc::common::Spanned;
+use deno_ast::swc::utils::ident::IdentLike;
+use deno_ast::view as ast_view;
 use if_chain::if_chain;
 use std::convert::TryFrom;
-use swc_atoms::JsWord;
-use swc_common::Spanned;
-use swc_ecmascript::utils::ident::IdentLike;
 
+#[derive(Debug)]
 pub struct NoDeprecatedDenoApi;
 
 const CODE: &str = "no-deprecated-deno-api";
@@ -46,7 +48,7 @@ impl LintRule for NoDeprecatedDenoApi {
 /// Extracts a symbol from the given expression if the symbol is statically determined (otherwise,
 /// return `None`).
 fn extract_symbol<'a>(expr: &'a ast_view::Expr) -> Option<&'a JsWord> {
-  use ast_view::{Expr, Lit, Tpl};
+  use deno_ast::view::{Expr, Lit, Tpl};
   match expr {
     Expr::Lit(Lit::Str(s)) => Some(s.value()),
     Expr::Ident(ident) => Some(ident.sym()),
@@ -170,7 +172,7 @@ impl Handler for NoDeprecatedDenoApiHandler {
       return;
     }
 
-    use ast_view::{Expr, ExprOrSuper};
+    use deno_ast::view::{Expr, ExprOrSuper};
     if_chain! {
       if let ExprOrSuper::Expr(Expr::Ident(obj)) = &member_expr.obj;
       if ctx.scope().is_global(&obj.inner.to_id());
