@@ -1,13 +1,14 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
 use super::{Context, LintRule, DUMMY_NODE};
 use crate::ProgramRef;
+use deno_ast::swc::ast::{Expr, ExprOrSuper};
+use deno_ast::swc::visit::Node;
+use deno_ast::swc::visit::Visit;
 use derive_more::Display;
-use swc_ecmascript::ast::{Expr, ExprOrSuper};
-use swc_ecmascript::visit::Node;
-use swc_ecmascript::visit::Visit;
 
-use swc_common::Span;
+use deno_ast::swc::common::Span;
 
+#[derive(Debug)]
 pub struct NoNonNullAssertedOptionalChain;
 
 const CODE: &str = "no-non-null-asserted-optional-chain";
@@ -74,7 +75,7 @@ impl<'c, 'view> NoNonNullAssertedOptionalChainVisitor<'c, 'view> {
 impl<'c, 'view> Visit for NoNonNullAssertedOptionalChainVisitor<'c, 'view> {
   fn visit_ts_non_null_expr(
     &mut self,
-    ts_non_null_expr: &swc_ecmascript::ast::TsNonNullExpr,
+    ts_non_null_expr: &deno_ast::swc::ast::TsNonNullExpr,
     _parent: &dyn Node,
   ) {
     match &*ts_non_null_expr.expr {
