@@ -2,8 +2,10 @@
 use super::{Context, LintRule};
 use crate::handler::{Handler, Traverse};
 use crate::{Program, ProgramRef};
-use swc_common::Spanned;
+use deno_ast::swc::common::Spanned;
+use deno_ast::view as ast_view;
 
+#[derive(Debug)]
 pub struct NoWith;
 
 const CODE: &str = "no-with";
