@@ -1,12 +1,13 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
 use super::{Context, LintRule, DUMMY_NODE};
 use crate::ProgramRef;
+use deno_ast::swc::ast::{TsModuleDecl, TsModuleName};
+use deno_ast::swc::visit::Node;
+use deno_ast::swc::visit::Visit;
 use once_cell::sync::Lazy;
 use regex::Regex;
-use swc_ecmascript::ast::{TsModuleDecl, TsModuleName};
-use swc_ecmascript::visit::Node;
-use swc_ecmascript::visit::Visit;
 
+#[derive(Debug)]
 pub struct PreferNamespaceKeyword;
 
 const CODE: &str = "prefer-namespace-keyword";
