@@ -8,6 +8,7 @@ const clippy = [
   "cargo",
   "clippy",
   "--all-targets",
+  "--all-features",
   ...mode,
   "--locked",
   "--",
@@ -28,11 +29,7 @@ console.log("deno lint");
 
 const dlint = `./target/${release ? "release" : "debug"}/examples/dlint`;
 const s2 = await Deno.run({
-  cmd: [
-    dlint,
-    "run",
-    "benchmarks/benchmarks.ts",
-  ],
+  cmd: [dlint, "run", "benchmarks/benchmarks.ts"],
   stdin: "null",
 }).status();
 
